Struct Mdf
pub struct Mdf { /* private fields */ }Expand description
Multi-function digital filter.
Implementations
impl Mdf
impl Mdf
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
pub const fn sitfcr(self, n: usize) -> Reg<Sitfcr, RW>
pub const fn sitfcr(self, n: usize) -> Reg<Sitfcr, RW>
This register is used to control the serial interfaces (SITFx).
pub const fn bsmxcr(self, n: usize) -> Reg<Bsmxcr, RW>
pub const fn bsmxcr(self, n: usize) -> Reg<Bsmxcr, RW>
This register is used to select the bitstream to be provided to the corresponding digital filter and to the SCD.
pub const fn dfltcr(self, n: usize) -> Reg<Dfltcr, RW>
pub const fn dfltcr(self, n: usize) -> Reg<Dfltcr, RW>
This register is used to control the digital filter x.
pub const fn dfltcicr(self, n: usize) -> Reg<Dfltcicr, RW>
pub const fn dfltcicr(self, n: usize) -> Reg<Dfltcicr, RW>
This register is used to control the main CIC filter.
pub const fn dfltrsfr(self, n: usize) -> Reg<Dfltrsfr, RW>
pub const fn dfltrsfr(self, n: usize) -> Reg<Dfltrsfr, RW>
This register is used to control the reshape and HPF filters.
pub const fn dfltintr(self, n: usize) -> Reg<Dfltintr, RW>
pub const fn dfltintr(self, n: usize) -> Reg<Dfltintr, RW>
This register is used to the integrator (INT) settings.
pub const fn oldcr(self, n: usize) -> Reg<Oldcr, RW>
pub const fn oldcr(self, n: usize) -> Reg<Oldcr, RW>
This register is used to configure the Out-of Limit Detector function.
pub const fn oldthlr(self, n: usize) -> Reg<Oldthlr, RW>
pub const fn oldthlr(self, n: usize) -> Reg<Oldthlr, RW>
This register is used for the adjustment of the Out-off Limit low threshold.
pub const fn oldthhr(self, n: usize) -> Reg<Oldthhr, RW>
pub const fn oldthhr(self, n: usize) -> Reg<Oldthhr, RW>
This register is used for the adjustment of the Out-off Limit high threshold.
pub const fn dlycr(self, n: usize) -> Reg<Dlycr, RW>
pub const fn dlycr(self, n: usize) -> Reg<Dlycr, RW>
This register is used for the adjustment stream delays.
pub const fn scdcr(self, n: usize) -> Reg<Scdcr, RW>
pub const fn scdcr(self, n: usize) -> Reg<Scdcr, RW>
This register is used for the adjustment stream delays.
pub const fn dfltier(self, n: usize) -> Reg<Dfltier, RW>
pub const fn dfltier(self, n: usize) -> Reg<Dfltier, RW>
This register is used for allowing or not the events to generate an interrupt.
pub const fn oeccr(self, n: usize) -> Reg<Oeccr, RW>
pub const fn oeccr(self, n: usize) -> Reg<Oeccr, RW>
This register contains the offset compensation value.